# Updated 2021 December 15

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(ggplot2)    # R package for plotting graphs
library(usmap)      # R package used with ggplot for plotting maps of the U.S.
library(data.table) # R package for using data.tables as augmented data.frames
datadir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/data" # SET THIS: top-level data directory
figuresdir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/figures" # SET THIS: directory in which to save figures
setwd(datadir)

## Data and programming notes:
#
# 1. Running this code requires fairly little computer RAM, less than 1 GB.
#

#### LOAD AND PREPARE DATA FOR THE MAP ####

hesitancy <- fread(file.path(datadir, "downloaded_manually", "hesitancy_rates.csv"))

hesitancy[, avg_hesitancy := (w25_hesitancy + w26_hesitancy + w27_hesitancy + w28_hesitancy + w29_hesitancy) / 5]
hesitancy[avg_hesitancy < 0.1, bin := "1"]
hesitancy[avg_hesitancy >= 0.1 & avg_hesitancy < 0.15, bin := "2"]
hesitancy[avg_hesitancy >= 0.15 & avg_hesitancy < 0.2, bin := "3"]
hesitancy[avg_hesitancy >= 0.2, bin := "4"]

#### FIGURE: PLOT AND SAVE THE MAP OF VACCINE HESITANCY RATES BY STATE ####

plot_usmap(regions = "states", data = hesitancy, values = "bin") +
  scale_fill_manual(name = "COVID-19 vaccine\n hesitancy rate (%)", values = c("#ffcec1", "#f27255", "#bb0000", "#330700"),
                    labels = c("7.3 - 9.9", "10.0 - 14.9", "15.0 - 19.9", "20.0 - 31.6")) +
  theme(legend.position = c(0.88, 0.22), legend.background = element_rect(color = "black", fill = "white"), text = element_text(size = 12))

ggsave(file.path(figuresdir, "Map_State_Vaccination_Hesitancy.pdf"), width = 10, height = 6, units = "in", dpi = 300)

#### END ####
