# Updated 2021 December 15

#### CODE PREAMBLE AND DESCRIPTION ####

## Code preamble: prepare workspace and load R packages

rm(list = ls())     # Clear workspace
library(dplyr)      # R packages used in forming tables
library(huxtable)   # R package for saving LaTex tables
library(data.table) # R package for using data.tables as augmented data.frames
datadir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/data" # SET THIS: top-level data directory
tablesdir = "~/Dropbox/Shared/VaccineLotteries/BarberWest_CodeData_Final/tables" # SET THIS: directory in which to save tables
setwd(datadir)

## Data and programming notes:
#
# 1. Running this code requires fairly little computer RAM, less than 1 GB.
#

#### LOAD AND PREPARE DATA FOR THE TABLE ####

vax.lotteries <- fread(file.path(datadir, "downloaded_manually", "Conditional_cash_lotteries_COVID19_vaccinations.csv"))

vax.lotteries[, announcement := format(as.Date(announcement, "%m/%d/%y"), "%B %d")]
vax.lotteries[, largest_prize := formatC(largest_prize, big.mark = ",", format = "fg")]
vax.lotteries[total_prize_value == "Unknown", total_prize_value := NA]
vax.lotteries[, total_prize_value := formatC(as.numeric(total_prize_value), big.mark = ",", format = "fg")]
vax.lotteries[total_prize_value == "NA", total_prize_value := "Unknown"]

#### SAVE THE TABLE ####

# Save the table as .tex using Huxtable

vax.lotteries.table <- huxtable(vax.lotteries, add_colnames = FALSE) %>%
  insert_row(after = 0, c("Announcement", "State", "Program", "Eligible", "Registration", "Largest", "Total prize value", "Exclusive", "Drawing")) %>%
  insert_row(after = 1, c("date (in 2021)", "", "name", "vaccinations", "process", "prize ($)", "(approximate $)", "prizes", "frequency")) %>%
  set_number_format(row = 2, value = "%4.0f") %>%
  set_align(col = everywhere, value = "left") %>% 
  set_align(col = 6:7, value = "right") %>%
  set_align(row = 1:2, col = 6:7, value = "left") %>% 
  set_bottom_border(row = 2, col = everywhere) %>%
  set_top_border(row = 1, col = everywhere) %>%
  set_bottom_border(row = 22, col = everywhere) %>%
  set_all_padding(value = 0) %>%
  set_bottom_padding(row = c(2,22), col = everywhere, value = 8) %>%
  set_top_padding(row = 1, col = everywhere, value = 8)
vax.lotteries.table
font_size(vax.lotteries.table) <- 8
sink(file.path(tablesdir, "State_Vaccination_Incentives.tex"))
print_latex(vax.lotteries.table, tabular_only = TRUE)
sink()

#### END ####
